searchNodes=[{"doc":"Stripy is a micro wrapper intended to be used for sending requests to Stripe&#39;s REST API. It is made for developers who prefer to work directly with the official API and provide their own abstractions on top if such are needed. Stripy takes care of setting headers, encoding the data, configuration settings, etc (the usual boring boilerplate); it also provides a parse/1 helper function for decoding. Some basic examples: iex&gt; Stripy.req(:get, &quot;subscriptions&quot;) {:ok, %HTTPoison.Response{...}} iex&gt; Stripy.req(:post, &quot;customers&quot;, %{&quot;email&quot; =&gt; &quot;a@b.c&quot;, &quot;metadata[user_id]&quot; =&gt; 1}) {:ok, %HTTPoison.Response{...}} You are expected to build your business logic on top of Stripy and abstract things such as Subscriptions and Customers; if that&#39;s not your cup of tea, check out &quot;stripity_stripe&quot; or &quot;stripe_elixir&quot; on Hex.","ref":"Stripy.html","title":"Stripy","type":"module"},{"doc":"Parses an HTTPoison response from a Stripe API call.","ref":"Stripy.html#parse/1","title":"Stripy.parse/1","type":"function"},{"doc":"Makes request to the Stripe API. Will return an HTTPoison standard response; see parse/1 for decoding the response body. You can specify custom headers to be included in the request to Stripe, such as Idempotency-Key, Stripe-Account or any other header. Just pass a map as the fourth argument. See example below. Examples iex&gt; Stripy.req(:get, &quot;subscriptions&quot;) {:ok, %HTTPoison.Response{...}} iex&gt; Stripy.req(:post, &quot;customers&quot;, %{&quot;email&quot; =&gt; &quot;a@b.c&quot;, &quot;metadata[user_id]&quot; =&gt; 1}) {:ok, %HTTPoison.Response{...}} iex&gt; Stripy.req(:post, &quot;customers&quot;, %{&quot;email&quot; =&gt; &quot;a@b.c&quot;}, %{&quot;Idempotency-Key&quot; =&gt; &quot;ABC&quot;}) {:ok, %HTTPoison.Response{...}}","ref":"Stripy.html#req/4","title":"Stripy.req/4","type":"function"},{"doc":"Constructs url with query params from given data.","ref":"Stripy.html#url/3","title":"Stripy.url/3","type":"function"},{"doc":"Mock server that would always return an empty, successful reply. Implement behaviour to provide your own responses; make sure the reply is an ok/error tuple, something resembling a real HTTPoison result. Body of the response should also be JSON encoded.","ref":"Stripy.MockServer.html","title":"Stripy.MockServer","type":"behaviour"},{"doc":"","ref":"Stripy.MockServer.html#request/3","title":"Stripy.MockServer.request/3","type":"function"},{"doc":"Request made by client.","ref":"Stripy.MockServer.html#c:request/3","title":"Stripy.MockServer.request/3","type":"callback"},{"doc":"Stripy Stripy is a micro wrapper intended to be used for sending requests to Stripe&#39;s REST API. It is made for developers who prefer to work directly with the official API and provide their own abstractions on top if such are needed. Stripy takes care of setting headers, encoding the data, configuration settings, etc (the usual boring boilerplate); it also makes testing easy by letting you plug your own mock server (see Testing section below). Some basic examples: iex&gt; Stripy.req(:get, &quot;subscriptions&quot;) {:ok, %HTTPoison.Response{...}} iex&gt; Stripy.req(:post, &quot;customers&quot;, %{&quot;email&quot; =&gt; &quot;a@b.c&quot;, &quot;metadata[user_id]&quot; =&gt; 1}) {:ok, %HTTPoison.Response{...}} Where subscriptions and customers are REST API resources. If you prefer to work with a higher-level library, check out &quot;stripity_stripe&quot; or &quot;stripe_elixir&quot; on Hex.","ref":"readme.html","title":"Stripy","type":"extras"},{"doc":"Add to your mix.exs as usual: def deps do [{:stripy, &quot;~&gt; 2.0&quot;}] end If you&#39;re not using application inference, then add :stripy to your applications list. Then configure the stripy app per environment like so: config :stripy, secret_key: &quot;sk_test_xxxxxxxxxxxxx&quot;, # required endpoint: &quot;https://api.stripe.com/v1/&quot;, # optional version: &quot;2017-06-05&quot;, # optional httpoison: [recv_timeout: 5000, timeout: 8000] # optional You may also use environment variables: config :stripy, secret_key: {:system, &quot;STRIPE_SECRET_KEY&quot;}, endpoint: {:system, &quot;STRIPE_ENDPOINT&quot;}, version: {:system, &quot;STRIPE_VERSION&quot;}","ref":"readme.html#installation","title":"Stripy - Installation","type":"extras"},{"doc":"You can disable actual calls to the Stripe API like so: # Usually in your test.exs. config :stripy, testing: true All functions that use Stripy would receive response {:ok, %{status_code: 200, body: &quot;{}&quot;}}. To provide your own responses, you need to configure a mock server: config :stripy, testing: true, mock_server: MyApp.StripeMockServer Here&#39;s an example mock server that mocks the /customer endpoint and returns a basic object for a customer with id cus_test defmodule MyApp.StripeMockServer do @behaviour Stripy.MockServer @ok_res %{status_code: 200} @impl Stripy.MockServer def request(:get, &quot;customers/cus_test&quot;, %{}) do body = Poison.encode!(%{&quot;email&quot; =&gt; &quot;email@email.com&quot;}) {:ok, Map.put(@ok_res, :body, body)} end end Now let&#39;s quickly write a naive function that gets user&#39;s billing email: def stripe_email(user) do {:ok, res} = Stripy.req(:get, &quot;customers/\#{user.stripe_id}&quot;) res[&quot;email&quot;] end We can test it like so: fake_user = %{stripe_id: &quot;cus_test&quot;} assert stripe_email(fake_user) == &quot;email@email.com&quot;","ref":"readme.html#testing","title":"Stripy - Testing","type":"extras"},{"doc":"You can add custom headers to the request by supplying a fourth parameter: Stripy.req(:post, &quot;charges&quot;, %{amount: 1000}, %{&quot;Idempotency-Key&quot; =&gt; &quot;123456&quot;})","ref":"readme.html#custom-headers","title":"Stripy - Custom headers","type":"extras"},{"doc":"Stripy: See LICENSE file.","ref":"readme.html#license","title":"Stripy - License","type":"extras"}]